@@ -17,7 +17,7 @@ class Service(BaseService):
 
         pattern = re.compile(
             r"""
-                (?P<apikey>[^:/]*)
+                (?P<apikey>[^@]+)
                 @(?:
                     \[(?P<ipv6host>[^/]+)\] |
                     (?P<ipv4host>[^/:]+)
