@@ -20,14 +20,14 @@ class Service(BaseService):
 
         pattern = re.compile(
             r"""
-                (?P<username>[^:/]*)
-                :(?P<password>.*)
+                (?P<username>[^:]+)
+                :(?P<password>[^@]+)
                 @(?:
                     \[(?P<ipv6host>[^/]+)\] |
                     (?P<ipv4host>[^/:]+)
                 )
                 (?::(?P<port>[\d]+))?
-                (?:/(?P<application>.*))?
+                (?:/(?P<application>.+))?
             """,
             re.X
         )
